"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.displayDateUTC = void 0;

var _antd = require("antd");

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _etherscanLogoCircle = require("../assets/images/logos/etherscan-logo-circle.svg");

var _attachment = _interopRequireDefault(require("./attachment"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const StyledCard = (0, _styledComponents.default)(_antd.Card)`
  background: #ffffff;
  border-radius: 12px;
  box-shadow: 0px 6px 36px #bc9cff;

  > .ant-card-body {
    padding: 0;
  }
`;
const StyledTitle = _styledComponents.default.div`
  color: #4d00b4;
`;
const StyledDescription = _styledComponents.default.div`
  color: #000000;
  padding: 1.5rem;
`;
const StyledFooter = _styledComponents.default.div`
  background: #f5f1fd;
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
`;
const StyledFooterBody = _styledComponents.default.div`
  padding: 1.5rem;
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;

  box-shadow: 0px 6px 36px #bc9cff;
`;
const StyledSubmitter = _styledComponents.default.div`
  color: #4d00b4;
  font-weight: 500;
`;
const StyledTime = _styledComponents.default.div`
  font-weight: 400;
`;

const truncateAddress = address => `${address.substring(0, 6)}...${address.substring(address.length - 4, address.length)}`;

const StyledEtherscanSVG = (0, _styledComponents.default)(_etherscanLogoCircle.ReactComponent)`
  width: 2rem;
  height: auto;
`;
const months = ["Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec"];

const displayDateUTC = dateString => {
  const _date = new Date(dateString);

  const date = String(_date.getUTCDate()).replace(/\b(\d{1})\b/g, "0$1");

  const month = _date.getUTCMonth();

  const year = _date.getUTCFullYear();

  const hours = String(_date.getUTCHours()).replace(/\b(\d{1})\b/g, "0$1");
  const minutes = String(_date.getUTCMinutes()).replace(/\b(\d{1})\b/g, "0$1");
  return `${date} ${months[month]} ${year} ${hours}:${minutes} UTC`;
};

exports.displayDateUTC = displayDateUTC;

const EvidenceCard = ({
  evidence,
  metaEvidence
}) => {
  const submittedAtDate = new Date(evidence.submittedAt * 1000);
  return _react.default.createElement(StyledCard, {
    style: {
      background: "white",
      borderRadius: "12px"
    },
    extra: _react.default.createElement("a", {
      href: `https://etherscan.com/address/${evidence.submittedBy}`
    }, _react.default.createElement(StyledEtherscanSVG, null)),
    title: _react.default.createElement(StyledTitle, null, evidence.evidenceJSON.title || evidence.evidenceJSON.name)
  }, _react.default.createElement(StyledDescription, null, evidence.evidenceJSON.description), _react.default.createElement(StyledFooter, null, _react.default.createElement(StyledFooterBody, null, _react.default.createElement(_antd.Row, null, _react.default.createElement(_antd.Col, {
    lg: 23
  }, _react.default.createElement(StyledSubmitter, null, "Submitted By:", " ", metaEvidence.aliases && metaEvidence.aliases[evidence.submittedBy] ? metaEvidence.aliases[evidence.submittedBy] : truncateAddress(evidence.submittedBy), _react.default.createElement(StyledTime, null, displayDateUTC(submittedAtDate)))), _react.default.createElement(_antd.Col, {
    lg: 1
  }, _react.default.createElement(_attachment.default, {
    URI: evidence.evidenceJSON.fileURI,
    extension: evidence.evidenceJSON.fileTypeExtension
  }))))));
};

var _default = EvidenceCard;
exports.default = _default;